% This function solves for equilibrium. Takes one input, where `s` is a struct
% of settings (e.g. parameters, numerical settings).
%
% written by  William Chen and Greg Phelan, Jan. 2021
function [fout, etaout, Dyn, Sharpe] = geteqm(s)
tic
% Determine starting boundary conditions

if s.ab~=s.ah
    s.ah=s.ab; %we assume constant productivities
end

% mult=1*1/s.issuance;

odeevnt =@(eta,f) evntfcn2(eta,f,s);
options = odeset('events',odeevnt,'AbsTol',1e-3);
% this function terminates integration of the ode when:
% or theta'=0 (or equiv) or theta=1 (or equiv)

%first solve imposing psi=1
odefun = @(eta,f) fnctpsi1(eta, f, s);

% since psi=1, q is just a function of theta, and that means we only need a
% single initial condition. In this case, eta-init.
% if eta-init is too low, theta hits thetastar too early, before smooth
% pasting
% if eta-init is too high, smooth pasting condition occurs first

eL=0;
eR=0.5;

for n=1:25

eta_init=.5*(eL+eR);

etastart=eta_init;

%set initial conditions using old way or new (probably correct) way
old_way=0;

if old_way
    F0(1)=s.issuance;
    F0(2)=(mult-s.issuance)/etastart;
%new way
else
     F0(1)=s.issuance;
     F0(2)=-(s.issuance-1)/etastart;
end

    etaspan = [etastart s.lmax];

% odeevnt =@(eta,f) evntfcn2(eta,f,s);
% options = odeset('events',odeevnt,'AbsTol',1e-3);

    [etaout,fout,te,ye,IE] = ode45(odefun,etaspan,F0,options);


    if IE==1
        %IE=1, theta=thetastar, eta-init too low
        %increase left boundary to increase eta range
        eL=etastart;
    else
        %IE=2, smooth pasting, eta-init too high
        %decrease right boundary to decrease eta range
        eR=etastart;
    end
%     dataset(n,etastart,te,ye,IE,eL,eR)
end


 [Dyn1, ~, ~,ERP1]=display_resultspsi1(etaout,fout,s);

%calculating if HH want to hold capital in the psi=1 eq'm
theta  = fout(:,1);
Qout= s.ab./(s.r.*(1+etaout.*(theta-1)));

omega = (1 - etaout) ./ ((1 - etaout) + theta .* etaout);
psi=Dyn1(:,1);
DS=deposit_spread(psi, etaout,Qout, s);

AP=(s.ab-s.ah)./Qout+s.g-s.gh-(ERP1-DS);
figure(200); hold on
plot(etaout,AP,'linewidth',3)
plot(etaout,0*etaout,':k')
hold off

fout1 = fout;
etaout1 = etaout;
etastart1=etastart;

%  keyboard
 %now solve with psi<=1

 if min(AP)>0
    %solve it again just for good measure? no, can skip.
%     odefun = @(eta,f) fnct(eta, f, s);

%     [etaout,fout,te,ye,IE] = ode45(odefun,etaspan,F0,options);
    [Dyn, risk_premium, Sharpe]=display_results(etaout1,fout1,s);
 else
    %we need to solve it with psi<1 possible this time. Let's start by
    %defining the right ODE function to use
    odefun = @(eta,f) fnct(eta, f, s);
    options = odeset('events',odeevnt,'RelTol',1e-10, 'AbsTol', 1e-7, 'InitialStep', 1e-7);
    %the initialization shouldn't move too much, so let's help ourselves

    eL=0;%etastart1/5;
    eR=etastart1*5;

    for n=1:25

    eta_init=.5*(eL+eR);

    etastart=eta_init;

    %old way
    old_way=0;

    if old_way
        F0(1)=s.issuance;
        F0(2)=(mult-s.issuance)/etastart;
    %new way
    else
         F0(1)=s.issuance;
         F0(2)=-(s.issuance-1)/etastart;
    end

        etaspan = [etastart s.lmax];

    % odeevnt =@(eta,f) evntfcn2(eta,f,s);
    % options = odeset('events',odeevnt,'AbsTol',1e-3);

        [etaout,fout,te,ye,IE] = ode45(odefun,etaspan,F0,options);


        if IE==1
            %IE=1, theta=thetastar, eta-init too low
            %increase left boundary to increase eta range
            eL=etastart;
        else
            %IE=2, smooth pasting, eta-init too high
            %decrease right boundary to decrease eta range
            eR=etastart;
        end
    %     dataset(n,etastart,te,ye,IE,eL,eR)
    end

     [Dyn, risk_premium, Sharpe]=display_results(etaout,fout,s);

 end

 % Calculate ergodic density
    [eta_density, density, cdf] = ergocalc(etaout, Dyn, s);

    color=s.color;
    start=s.gstart;
    etastar=max(etaout);

    disp('figure 27 PDF eta/eta*')
    figure(27)
    e11=eta_density/etaout(end);
    plot(e11,density,'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta/\eta^*$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1])
    ylabel('$f(\eta)$','fontsize',14,'Rotation',0,'FontWeight','b');
    title('Shifted Stationary Density','FontSize',s.fontsize)
    ylim([0 120])

    disp('figure 28 PDF')
    figure(28)
        plot(eta_density,density,'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$f(\eta)$','FontSize',s.fontsize,'FontWeight','b')
    title('Stationary Distribution')
    xlim([start 1.05*etastar])


toc

end
