% This function solves for equilibrium. Takes one input, where `s` is a struct
% of settings (e.g. parameters, numerical settings).
%
% written by  William Chen and Greg Phelan, Jan. 2021
%does not first solve imposing psi=1; just solve psi<1 the first time

function [fout, etaout, Dyn, risk_premium, Sharpe,ERP,DS_avg] = geteqm2(s)
tic
% Determine starting boundary conditions

if s.ab~=s.ah
    s.ah=s.ab; %we assume constant productivities
end

% mult=1*1/s.issuance;

odeevnt =@(eta,f) evntfcn2(eta,f,s);
% options = odeset('events',odeevnt,'AbsTol',1e-3);
% this function terminates integration of the ode when:
% or theta'=0 (or equiv) or theta=1 (or equiv)

%first solve imposing psi=1
% odefun = @(eta,f) fnctpsi1(eta, f, s);

% since psi=1, q is just a function of theta, and that means we only need a
% single initial condition. In this case, eta-init.
% if eta-init is too low, theta hits thetastar too early, before smooth
% pasting
% if eta-init is too high, smooth pasting condition occurs first

eL=0;
eR=0.5;

    %we need to solve it with psi<1 possible this time. Let's start by
    %defining the right ODE function to use
    odefun = @(eta,f) fnct(eta, f, s);
    options = odeset('events',odeevnt,'RelTol',1e-10, 'AbsTol', 1e-7, 'InitialStep', 1e-7);
    %the initialization shouldn't move too much, so let's help ourselves


    for n=1:30

    eta_init=.5*(eL+eR);

    etastart=eta_init;

    %old way
    old_way=0;

    if old_way
        F0(1)=s.issuance;
        F0(2)=(mult-s.issuance)/etastart;
    %new way
    else
         F0(1)=s.issuance;
         F0(2)=-(s.issuance-1)/etastart;
    end

        etaspan = [etastart s.lmax];

    % odeevnt =@(eta,f) evntfcn2(eta,f,s);
    % options = odeset('events',odeevnt,'AbsTol',1e-3);

        [etaout,fout,te,ye,IE] = ode45(odefun,etaspan,F0,options);


        if IE==1
            %IE=1, theta=thetastar, eta-init too low
            %increase left boundary to increase eta range
            eL=etastart;
        else
            %IE=2, smooth pasting, eta-init too high
            %decrease right boundary to decrease eta range
            eR=etastart;
        end
    %     dataset(n,etastart,te,ye,IE,eL,eR)
    end

    %IE=2, smooth pasting



     [Dyn, risk_premium, Sharpe,ERP]=display_results(etaout,fout,s);


    % Calculate ergodic density
    [eta_density, density, cdf] = ergocalc(etaout, Dyn, s);

    color=s.color;
    start=s.gstart;
    etastar=max(etaout);

    disp('figure 27 PDF eta/eta*')
    figure(27)
%     subplot(1,2,2); hold on
    e11=eta_density/etaout(end);
    plot(e11,density,'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta/\eta^*$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1])
    ylabel('$f(\eta)$','fontsize',14,'Rotation',0,'FontWeight','b');
    title('Shifted Stationary Density','FontSize',s.fontsize)
    ylim([0 120])

    disp('figure 28 PDF')
    figure(28)
        plot(eta_density,density,'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta, level of bank equity$','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$f(\eta)$','FontSize',s.fontsize,'FontWeight','b')
    title('Stationary Distribution')
    xlim([start 1.05*etastar])

    theta  = fout(:,1);
    Qout= s.ab./(s.r.*(1+etaout.*(theta-1)));
    psi=Dyn(:,1);
    DS=deposit_spread(psi, etaout,Qout, s);

    DS0=interp1(etaout, DS,eta_density, s.interp);
    int=density(2:end)'*diff(eta_density);
    DS_avg=(DS0(2:end).*density(2:end))'*diff(eta_density)/int;


toc

end
