function [fp, dyn, expert_premium, Sharpe] = fnctLinear(eta, f, s)
% [fp dyn] = fnct(eta, f, s)
% takes scalar eta, a 4x1 vector f = [theta, theta', q, q'], and parameters
% r, rho, a, sigma, g, delta_, and computes fp, the derivative of f with
% respect to eta, as well as dyn = [psi, sigma_eta*eta, sigma_q, mu_eta*eta, mu_q]
%
%
% written by Greg Phelan

    
%tol=1e-10; %this is used for computational purposes very very near zero.

%by assumption banks hold all capital
psi=1;
lambda=1;                    

phiL=s.phiL;%adjustLiqPref(1-eta,s);

p2=1;


    % VOLATILITY COMPUTATION 
    amplification = 1 - f(4)/f(3)*(psi - eta);      
    sigma_eta_eta = s.sigma*(psi - eta)/amplification;             
    sigma_q = sigma_eta_eta*f(4)/f(3); 
    sigma_theta = sigma_eta_eta*f(2)/f(1);
    risk_premium = (- sigma_theta)*(s.sigma + sigma_q);
    Sharpe=- sigma_theta;
   
    
    canholdtree=0;
    if canholdtree==1
        if risk_premium>phiL
            psi=fzero(@(x) getpsiFun(x,eta,f,s),1);
            amplification = 1 - f(4)/f(3)*(psi - eta);      
            sigma_eta_eta = s.sigma*(psi - eta)/amplification;             
            sigma_q = sigma_eta_eta*f(4)/f(3); 
            sigma_theta = sigma_eta_eta*f(2)/f(1);
            risk_premium = (- sigma_theta)*(s.sigma + sigma_q);
            Sharpe=- sigma_theta;
        end
    end


mu_q = s.r - 1/f(3) - s.g - s.sigma*sigma_q+risk_premium-phiL;  


mu_theta=phiL;

mu_eta_eta = (psi - eta)*(risk_premium-(s.sigma + sigma_q)^2) + eta*(1/f(3));
mu_eta=mu_eta_eta/eta;
sigma_eta=sigma_eta_eta/eta;

qpp = 2*(mu_q*f(3) - f(4)*mu_eta_eta)/sigma_eta_eta^2; 
thetapp = 2*(mu_theta*f(1) - f(2)*mu_eta_eta)/sigma_eta_eta^2; 

fp = [f(2); thetapp; f(4); qpp];


expert_premium = risk_premium;
% Sharpe=(mu_a-s.r)/(s.sigma + sigma_q);

dyn = [psi, sigma_eta, sigma_q, mu_eta, mu_q, mu_theta,p2,lambda];


end

function out=getpsiFun(psi,eta,f,s)

    amplification = 1 - f(4)/f(3)*(psi - eta);      
    sigma_eta = s.sigma*(psi - eta)/amplification;             
    sigma_q = sigma_eta*f(4)/f(3); 
    sigma_theta = sigma_eta*f(2)/f(1);
    risk = (- sigma_theta)*(s.sigma + sigma_q);
    out=risk-phiL;
end
    


