function [Dyn, risk_premium, Sharpe, ERP]=display_results(etaout,fout,s)

theta=fout(:,1);
thetap=fout(:,2);

Q= s.ab./(s.r.*(1+etaout.*(theta-1)));



start=s.gstart;
color=s.color;

% if sum(fout(:,4)<0)>0
% N = find(fout(:,4)<0,1);%length(etaout);
% else
    N=length(etaout);
% end
s.N=N;
Dyn = zeros(N, 9);
fp=zeros(N,2);
Sharpe=zeros(N,1);
risk_premium=zeros(N,1);
ERP=Sharpe;

% calculate the psi, as well as drifts and volatilities
for n = 1:N
    [fp(n,:), Dyn(n,:),risk_premium(n,:),Sharpe(n,:),ERP(n)] = fnct(etaout(n), fout(n,:), s);
end

thetapp=fp(:,2);

Qp      = -Q .* s.r .* (thetap .* etaout + (theta - 1)) ./ (s.r .* (1 + (theta - 1) .* etaout) );
DS        = deposit_spread(Dyn(:, 1),  etaout, Q,s);

%compute risk free rate analytically based on constant output
drf=s.r+s.g-s.sigma^2;
muQ=Dyn(:,9);


etastar=max(etaout);

Leverage=Dyn(:,1)./etaout-1;

disp('figure 1 Leverage')
%plot leverage
figure(1); hold on
    plot(etaout,Leverage,'Color', color,'linewidth',s.width);
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Leverage','FontSize',s.fontsize,'FontWeight','b')
    title('Aggregate Bank Leverage','FontSize',s.fontsize)
    xlim([start 1.05*etastar])

disp('figure 2 dQ dEta')
%plot drifts, vols
figure(2);
    subplot(2,2,1); hold on
    plot(etaout(1:N), Dyn(1:N, 4), 'Color', color,'linewidth',s.width);
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\mu_\eta$  ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlim([start 1.05*etastar])
    ylim([0 1.05*max(Dyn(1:N, 4))]);

    subplot(2,2,2); hold on
    plot(etaout(1:N), Dyn(1:N, 2), 'Color', color,'linewidth',s.width);
    ylabel('$\sigma_\eta$','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])
    ylim([0 1.05*max(Dyn(1:N, 2))]);

    subplot(2,2,3); hold on
    plot(etaout(1:N), muQ(1:N), 'Color', color,'linewidth',s.width);
    ylabel('$\mu_q$ ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])

    subplot(2,2,4); hold on
    plot(etaout(1:N), Dyn(1:N,3), 'Color', color,'linewidth',s.width);
    ylabel('$\sigma_q$ ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([s.start 1.05*etastar])



disp('figure 3 Q')
%plot q
figure(3); hold on
    plot(etaout, Q, 'Color', color,'linewidth',s.width);
    title('Asset Price, $q(\eta)$','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$q$','FontSize',s.fontsize,'Rotation',0,'FontWeight','b')


    % Calculate consumption and flow utility
    Ch=s.ab;
    hh_deposit_share = (Dyn(:, 1) - etaout);% ./ (1 - etaout);
	conv_yield       = convenience_yield(hh_deposit_share.*Q*s.r, etaout,0, s);
    flow_util        = log(Ch) + conv_yield ;

disp('figure 4 Flow Utility')
figure(4); hold on
    plot(etaout, flow_util, 'Color', color,'linewidth',s.width);
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Flow Utility','FontSize',s.fontsize,'FontWeight','b')
    title('Output and Liquidity','FontSize',s.fontsize)
    xlim([start 1.05*etastar])

disp('figure 5 Deposit SPREAD')
figure(5); hold on
    plot(etaout(1:N), 100*DS, 'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Deposit Spread, pct','FontSize',s.fontsize,'FontWeight','b')
    title('Deposit Spread','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])

disp('figure 6 Deposit RATE')
figure(6); hold on
    plot(etaout(1:N), 100*(drf-DS), 'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Deposit Rate, pct','FontSize',s.fontsize,'FontWeight','b')
    title('Deposit Rate','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])



[V, H] = get_welfare(etaout, fout, Dyn, s);
    welfare=H;
disp('figure 9 Welfare')
%Household Welfare
figure(9); hold on
    plot(etaout, welfare, 'Color', color,'linewidth',s.width);
    title('Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$H(\eta)$','FontSize',s.fontsize,'FontWeight','b')

disp('figure 10 Welfare Shift, V-V(end)')
figure(10); hold on
    plot(etaout, welfare-welfare(end), 'Color', color,'linewidth',s.width);
    title('Normalized Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$V-V(\bar{\eta})$','FontSize',s.fontsize,'FontWeight','b')

%plot rf
disp('figure 12 dRf Risk-free RATE')
figure(12); hold on
    plot(etaout(1:N), drf, 'Color', color,'linewidth',s.width);
    title('Risk-Free Rate','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$dr_f$','FontSize',s.fontsize,'FontWeight','b')


disp('figure 13 PSI Bank Holdings')
figure(13); hold on
    plot(etaout(1:N), Dyn(1:N,1), 'Color', color,'linewidth',s.width);
    title('Bank Holdings','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\psi$','FontSize',s.fontsize,'FontWeight','b')

disp('figure 15 THETA')
figure(15)
    plot(etaout(1:N),fout(1:N,1),'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\theta$','FontSize',s.fontsize,'FontWeight','b','Rotation',0)
    title('$\theta(\eta)$')
    xlim([start 1.05*etastar])
    ylim([.9 1.05*max(fout(1:N,1))])

    disp('figure 25 SHARPE RATIO')
figure(25)
    plot(etaout(1:N),Sharpe(1:N,1),'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Sharpe','FontSize',s.fontsize,'FontWeight','b')
    title('Sharpe Ratio')
    xlim([start 1.05*etastar])




disp('figure 33 Risk PREMIUM')
figure(33)
    plot(etaout(1:N),risk_premium(1:N,1),'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Premium','FontSize',s.fontsize,'FontWeight','b')
    title('Risk Premium')
    xlim([start 1.05*etastar])

disp('figure 63 Sigma_C')
figure(63)
    plot(etaout(1:N),Dyn(1:N,5),'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\sigma_c$','FontSize',s.fontsize,'FontWeight','b')
    title('$\sigma_c$')
    xlim([start 1.05*etastar])

disp('figure 66 Qprime')
figure(66)
    plot(etaout(1:N),Qp,'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$Q^\prime$','FontSize',s.fontsize,'FontWeight','b')
    title('$Q^\prime$')
    xlim([start 1.05*etastar])

    disp('figure 67 Omega')
figure(67)
    plot(etaout(1:N),Dyn(:,6),'Color', color,'linewidth',s.width); hold on
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\omega$','FontSize',s.fontsize,'FontWeight','b')
    title('Omega $\omega$')
    xlim([start 1.05*etastar])


    disp('figure 68 sigmaq')
figure(68)
    plot(etaout(1:N), Dyn(1:N,3), 'Color', color,'linewidth',s.width); hold on
    ylabel('$\sigma_q$ ','fontsize',14,'FontWeight','b');
    xlabel('$\eta$, bank equity wealth share','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])
    title('Volatility of asset price','FontSize',s.fontsize)

% disp('figure 104 rV and flow Utility')
%     ww=s.r*V-(s.g-s.sigma^2/2);
%     figure(104); hold on
%     plot(etaout, flow_util, strcat(':',s.color),'linewidth',s.width);
%     plot(etaout, ww, strcat('-',s.color),'linewidth',s.width);
%     xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
%     ylabel('Flow Utility and rV','FontSize',s.fontsize,'FontWeight','b')
%     title('Flow Utility and rV','FontSize',s.fontsize)
%     xlim([start 1.05*etastar])
%     legend('flow utility','rV')
