function [Dyn, risk_premium, Sharpe,ERP]=display_resultspsi1(etaout,fout,s)


theta=fout(:,1);
thetap=fout(:,2);

Q= s.ab./(s.r.*(1+etaout.*(theta-1)));


    
start=s.gstart;
color=strcat('--',s.color);

N=length(etaout);
s.N=N;
Dyn = zeros(N, 9);
fp=zeros(N,2);
Sharpe=zeros(N,1);
ERP=Sharpe;
risk_premium=zeros(N,1);

% calculate the psi, as well as drifts and volatilities 
for n = 1:N
    [fp(n,:), Dyn(n,:),risk_premium(n,:),Sharpe(n,:),ERP(n,:)] = fnctpsi1(etaout(n), fout(n,:), s);
end

thetapp=fp(:,2);

Qp      = -Q .* s.r .* (thetap .* etaout + (theta - 1)) ./ (s.r .* (1 + (theta - 1) .* etaout) );
    
DS        = deposit_spread(Dyn(:, 1), etaout, Q,s);

%compute analytically based on constant output
drf=s.r+s.g-s.sigma^2;

muQ=Dyn(:,9);

etastar=max(etaout);

Leverage=Dyn(:,1)./etaout-1;

figure(1); hold on
    plot(etaout,Leverage,color,'linewidth',s.width);
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Leverage','FontSize',s.fontsize,'FontWeight','b')
    title('Aggregate Bank Leverage','FontSize',s.fontsize)
    xlim([s.start 1.05*etastar])

figure(2);
    subplot(2,2,1); hold on
    plot(etaout(1:N), Dyn(1:N, 4), color,'linewidth',s.width); 
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    ylabel('\mu_\eta  ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlim([start 1.05*etastar])
    ylim([0 1.05*max(Dyn(1:N, 4))]);

    subplot(2,2,2); hold on
    plot(etaout(1:N), Dyn(1:N, 2), color,'linewidth',s.width);   
    ylabel('\sigma_\eta ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar]) 
    ylim([0 1.05*max(Dyn(1:N, 2))]);

    subplot(2,2,3); hold on
    plot(etaout(1:N), muQ(1:N), color,'linewidth',s.width);   
    ylabel('\mu_q ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])

    subplot(2,2,4); hold on
    plot(etaout(1:N), Dyn(1:N,3), color,'linewidth',s.width);   
    ylabel('\sigma_q ','fontsize',14,'Rotation',90,'FontWeight','b');
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    xlim([s.start 1.05*etastar])

figure(3); hold on
    plot(etaout, Q, color,'linewidth',s.width);
    title('Asset Price, q(\eta)','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('q','FontSize',s.fontsize,'Rotation',0,'FontWeight','b')

    Ch=s.ab;
    hh_deposit_share = (Dyn(:, 1) - etaout);% ./ (1 - etaout);
	conv_yield       = convenience_yield(hh_deposit_share.*Q*s.r, etaout,0, s);
    flow_util        = log(Ch) + conv_yield ;

figure(4); hold on
    plot(etaout, flow_util, color,'linewidth',s.width);
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Flow Utility','FontSize',s.fontsize,'FontWeight','b')
    title('Output and Liquidity','FontSize',s.fontsize)
    xlim([start 1.05*etastar])



figure(5); hold on
    plot(etaout(1:N), 100*DS, color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Deposit Spread, pct','FontSize',s.fontsize,'FontWeight','b')
    title('Deposit Spread','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])

figure(6); hold on
    plot(etaout(1:N), 100*(drf-DS), color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Deposit Rate, pct','FontSize',s.fontsize,'FontWeight','b')
    title('Deposit Rate','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])
   
figure(13); hold on
    plot(etaout(1:N), Dyn(1:N,1), color,'linewidth',s.width);
    title('Bank Holdings','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('\psi','FontSize',s.fontsize,'FontWeight','b')

    [V, H] = get_welfare(etaout, fout, Dyn, s);    
    welfare=H;

figure(9); hold on
    plot(etaout, welfare, color,'linewidth',s.width);
    title('Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('H(\eta)','FontSize',s.fontsize,'FontWeight','b')
    
figure(10); hold on
    plot(etaout, welfare-welfare(end), color,'linewidth',s.width);
    title('Normalized Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('V-V(end)','FontSize',s.fontsize,'FontWeight','b')

figure(12); hold on
    plot(etaout(1:N), drf, color,'linewidth',s.width);
    title('Risk-Free Rate','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('dr_f','FontSize',s.fontsize,'FontWeight','b')
 




figure(15)
    plot(etaout(1:N),fout(1:N,1),color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('\theta','FontSize',s.fontsize,'FontWeight','b','Rotation',0)
    title('\theta(\eta)')
    xlim([start 1.05*etastar])
    ylim([.9 1.05*max(fout(1:N,1))])
    
figure(25)
    plot(etaout(1:N),Sharpe(1:N,1),color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Sharpe','FontSize',s.fontsize,'FontWeight','b')
    title('Sharpe Ratio')
    xlim([start 1.05*etastar])

figure(33)
    plot(etaout(1:N),risk_premium(1:N,1),color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Premium','FontSize',s.fontsize,'FontWeight','b')
    title('Risk Premium')
    xlim([start 1.05*etastar])
    
    
    [eta_density, density, ~] = ergocalc(etaout, Dyn, s);

    figure(27)
    e11=eta_density/etaout(end);
    plot(e11,density,color,'linewidth',s.width); hold on
    xlabel('\eta/\eta^*','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1])
    ylabel('f(\eta)','fontsize',14,'Rotation',0,'FontWeight','b');
    title('Shifted Stationary Density','FontSize',s.fontsize)
    ylim([0 120])
    
    figure(28)
        plot(eta_density,density,color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('f(\eta)','FontSize',s.fontsize,'FontWeight','b')
    title('Stationary Distribution')
    xlim([start 1.05*etastar])
    
figure(66)
    plot(etaout(1:N),Qp,color,'linewidth',s.width); hold on
    xlabel('\eta, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Q^\prime','FontSize',s.fontsize,'FontWeight','b')
    title('Q^\prime')
    xlim([start 1.05*etastar]) 
    
    
    ww=s.r*V-(s.g-s.sigma^2/2);
    figure(104); hold on
    plot(etaout, flow_util, strcat(':',s.color),'linewidth',s.width);
    plot(etaout, ww, strcat('--',s.color),'linewidth',s.width);
    xlabel('\eta','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Flow Utility and rV','FontSize',s.fontsize,'FontWeight','b')
    title('Utility and V','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    legend('flow utility','rV')

    
