function [fp, dyn, risk_premium, Sharpe, ERP] = fnct(eta, f, s)
% takes scalar eta, a 2x1 vector f = [theta, theta'], and parameters
% s, and computes fp, the derivative of f with respect to eta.
% Since ab=ah, output is constant, and we define Q and Q' from f, eta
% psi is determined by asset pricing returns conditions
%
% written by William Chen and Greg Phelan, Jan. 2022
%let's start by setting psi=1 (imposed) and see if we can't solve this

	% Set up
	theta  = f(1);
	thetap = f(2);
% 	Q      = f(3);

%we calcaulte Q MC for consumption, constant productivity
    Q      = s.ab/(s.r*(1+eta*(theta-1)));
    Qp      = -Q * s.r * (thetap * eta + (theta - 1)) / (s.r * (1 + (theta - 1) * eta) );

    omega = (1 - eta) / ((1 - eta) + theta * eta);
	% Asset pricing pins down psi. We first check the psi=1 case
    psi = 1; %consumption_market_clearing(eta, theta, Q, 'psi', s);
	
    DS=deposit_spread(psi,  eta,Q, s);
    sigma_Q = Qp * (psi - eta) * s.sigma / (Q - Qp * (psi - eta));
    ssQ     = s.sigma + sigma_Q;
    sigma_eta     = (psi / eta - 1) * ssQ;
	eta_sigma_eta = sigma_eta * eta;
    sigma_theta   = eta_sigma_eta * thetap / theta;
    
    ERP=-sigma_theta*ssQ;
    
    %need to check that ERP<DS
    if ERP>DS %problem
%         keyboard
        psiL=0;
        psiR=1;
        for n=1:50
            psi0=.5*(psiL+psiR);
            out=getpsifromAP(psi0,eta,s,Qp,Q,theta,thetap);
            if out<0 %psi too high
                psiR=psi0;
            else
                psiL=psi0;
            end
        end
        psi=psi0;
        DS=deposit_spread(psi,  eta, Q,s);
        sigma_Q = Qp * (psi - eta) * s.sigma / (Q - Qp * (psi - eta));
        ssQ     = s.sigma + sigma_Q;
        sigma_eta     = (psi / eta - 1) * ssQ;
        eta_sigma_eta = sigma_eta * eta;
        sigma_theta   = eta_sigma_eta * thetap / theta;
        ERP=-sigma_theta*ssQ;
    end
        

    % Calculate leverage
    xh    = (1 - psi) / (1 - eta);                 % household leverage
    xb    = psi / eta;                             % bank leverage

    % Calculate volatilities of eta, theta, and household consumption
    sigma_eta     = (psi / eta - 1) * ssQ;
	eta_sigma_eta = sigma_eta * eta;
    sigma_theta   = eta_sigma_eta * thetap / theta;
    sigma_ch      = s.sigma;%(omega * (xh - xb) + xb) * ssQ + (1 - omega) * sigma_theta;
    %we can hard-code sigma_ch because this is a tree economy
    % Calculate drifts
    T        = s.tau; % transfers
        mu_theta = T + DS + sigma_ch * sigma_theta;
        mu_eta   = (s.ab ) / Q - T + (xb - 1) * ((sigma_ch - sigma_theta) - ssQ) * ssQ;
%     end

    % Calculate differential equation for thetapp
    eta_mu_eta = eta * mu_eta;
    thetapp    = 2 * (mu_theta * theta - thetap * eta_mu_eta) / eta_sigma_eta^2;

    fp = [thetap; thetapp];%; Qp];

    % Calculate remaining values of interest
%     if lc
%         % excess_returns = E[dr_b] - dr_d = (s.ab - s.ah) / Q + sigma_ch * ssQ + DS
%         % and E[dr_b] - dr_d = risk_premium + liquidity_premium
%         risk_premium = (s.ab - s.ah) / Q + sigma_ch * ssQ + DS - liquidity_premium
%     else % HH risk premium + excess risk premium
        risk_premium = (sigma_ch - sigma_theta) * ssQ;
%     end
    Sharpe           = (risk_premium) / ssQ; % (E[dr_b] - dr_d) / vol[dr_b]
    
    muQ=s.r+ERP-DS-(s.ab ) ./ Q;
    
    dyn = [psi, sigma_eta, sigma_Q, mu_eta, sigma_ch, omega, mu_theta, sigma_theta,muQ];
    
    
        
end

function out=getpsifromAP(psi,eta,s,Qp,Q,theta,thetap)
    
    DS=deposit_spread(psi,  eta, Q,s);
    sigma_Q = Qp * (psi - eta) * s.sigma / (Q - Qp * (psi - eta));
    ssQ     = s.sigma + sigma_Q;
    sigma_eta     = (psi / eta - 1) * ssQ;
	eta_sigma_eta = sigma_eta * eta;
    sigma_theta   = eta_sigma_eta * thetap / theta;
    
    ERP=-sigma_theta*ssQ;
    out=DS-ERP;
    
end
