function [fp, dyn, risk_premium, Sharpe,ERP] = fnctpsi1(eta, f, s)
% takes scalar eta, a 3x1 vector f = [theta, theta', Q], and parameters
% s, and computes fp, the derivative of f with respect to eta.
% Capital growth is driven by internal investment.
%
% written by William Chen and Greg Phelan, Jan. 2022
%let's start by setting psi=1 (imposed) and see if we can't solve this

	% Set up
	theta  = f(1);
	thetap = f(2);
% 	Q      = f(3);

%we calcaulte Q using psi=1, no investment, etc
    Q      = s.ab/(s.r*(1+eta*(theta-1)));


	% Market clearing for consumption pins down psi
    psi = 1; %consumption_market_clearing(eta, theta, Q, 'psi', s);
	
    % psi = (Q * (s.r * (1 + (theta - 1) * eta) + s.eps1 / s.eps2) - ...
    %     s.ah - (exp(s.eps2 * s.delta) - s.eps2 * s.delta) / s.eps2) / (s.ab - s.ah);

    % Calculate share of household wealth held in non-bank net worth
	% omega = nh / wh = nh / (nh + theta nb)
    %       = (nh / (QK)) / ((nh + theta nb) / (QK))
    %       = (1 - eta) / ((1 - eta) + theta eta)
	omega = (1 - eta) / ((1 - eta) + theta * eta);

    % Compute deposit spread, given psi, omega, and eta
%     DS = s.phiL;
    DS=deposit_spread(psi, eta, Q,s);

%     % Check if leverage constrained
%     if isfield(s, 'leverage_constraint')
%         [L, dL] = leverage_constraint(eta, f, s.leverage_constraint);
%     else
%         L = Inf;
%     end
% 
%     if psi >= eta * (L + 1)
%         psi = eta * (L + 1);
%         lc = true;
%     else
%         lc = false;
%     end

    % Calculate ssq and Qp
%     if psi >= 1 % Enforce that psi <= 1, and calculate Qp analytically
%         psi     = 1;
        Qp      = -Q * s.r * (thetap * eta + (theta - 1)) / (s.r * (1 + (theta - 1) * eta) );
        sigma_Q = Qp * (psi - eta) * s.sigma / (Q - Qp * (psi - eta));
        ssQ     = s.sigma + sigma_Q;
%     elseif lc
%         % Obtain Qp directly from market-clearing for consumption
%         Qp      = ((s.ab - s.ah) * (L + 1 + eta * dL) - Q * s.r * (thetap * eta + theta - 1)) / ...
%             (s.r * (1 + (theta - 1) * eta) + s.eps1 / s.eps2);
%         sigma_Q = Qp * (psi - eta) * s.sigma / (Q - Qp * (psi - eta));
%         ssQ     = s.sigma + sigma_Q;
%     else % Apply asset pricing condition to solve for ssq = sigma + sigma_q since psi < 1
%         ssQ     = sqrt(((s.ab - s.ah) / Q - liquidity_premium + DS) * ...
%               theta / -thetap / (psi - eta));
%         sigma_Q = ssQ - s.sigma;
%         Qp      = Q * sigma_Q / ((psi - eta) * ssQ);
%     end

    % Calculate leverage
    xh    = (1 - psi) / (1 - eta);                 % household leverage
    xb    = psi / eta;                             % bank leverage

    % Calculate volatilities of eta, theta, and household consumption
    sigma_eta     = (psi / eta - 1) * ssQ;
	eta_sigma_eta = sigma_eta * eta;
    sigma_theta   = eta_sigma_eta * thetap / theta;
    sigma_ch      = (omega * (xh - xb) + xb) * ssQ + (1 - omega) * sigma_theta;

    % Calculate drifts
    T        = s.tau; % transfers
%     iota     = (s.eps1 * Q - (exp(s.eps2 * s.delta) - s.eps2 * s.delta)) / s.eps2;
%     if lc
%         mu_theta = T - (xb - 1) * DS  + sigma_ch * sigma_theta - ...
%             xb * ((s.ab - s.ah) / Q - (-sigma_theta * ssQ ));
%         mu_eta   = xb * s.ab / Q - (xb - 1) * s.ah / Q  ...
%              + (xb - 1) * DS - T ...
%             + (xb - 1) * (sigma_ch - ssQ) * ssQ;
%     else
        mu_theta = T + DS + sigma_ch * sigma_theta;
        mu_eta   = (s.ab ) / Q - T + (xb - 1) * ((sigma_ch - sigma_theta) - ssQ) * ssQ;
%     end

    % Calculate differential equation for thetapp
    eta_mu_eta = eta * mu_eta;
    thetapp    = 2 * (mu_theta * theta - thetap * eta_mu_eta) / eta_sigma_eta^2;

    fp = [thetap; thetapp];%; Qp];

    % Calculate remaining values of interest
%     if lc
%         % excess_returns = E[dr_b] - dr_d = (s.ab - s.ah) / Q + sigma_ch * ssQ + DS
%         % and E[dr_b] - dr_d = risk_premium + liquidity_premium
%         risk_premium = (s.ab - s.ah) / Q + sigma_ch * ssQ + DS - liquidity_premium
%     else % HH risk premium + excess risk premium
        risk_premium = (sigma_ch - sigma_theta) * ssQ;
        ERP          = -sigma_theta* ssQ;
%     end
    Sharpe           = (risk_premium) / ssQ; % (E[dr_b] - dr_d) / vol[dr_b]
    muQ=s.r+ERP-DS-(s.ab ) ./ Q;
    
    dyn = [psi, sigma_eta, sigma_Q, mu_eta, sigma_ch, omega, mu_theta, sigma_theta,muQ];
end
