close all
clear

% Change default axes fonts
set(0,'DefaultAxesFontName', 'Times New Roman')
set(0,'DefaultAxesFontSize', 14)

% Change default text fonts
set(0,'DefaultTextFontname', 'Times New Roman')
set(0,'DefaultTextFontSize', 14)

%% Graphics
s.color = 'k';
set(groot, 'DefaultLineLinewidth', 3);
s.gpath = '../figures/';

%% first run without the liquidity adjustment, as a baseline
% Save plots?
save_plots = 1;

% Initialize parameters
parameters;
s.beta_2=1;

gpath = strcat(s.gpath, 'LiqAdj/');

b1=.6;
s.beta_1=b1/100/s.r*(1-.18+1);

s.color=[0 0.4470 0.7410];
geteqm2(s);

b2=.5;
s.beta_1=b2/100/s.r*(1-.18+1);
s.color='k';
geteqm2(s);

b3=.4;
s.beta_1=b3/100/s.r*(1-.18+1);
s.color=[0.8500 0.3250 0.0980];
geteqm2(s);

%%
% Save results!
if save_plots
   if ~isfolder(gpath)
       mkdir(gpath)
   end

   figure(10)
   ylabel('$V(\eta)-V(\bar{\eta})$','interpreter','latex')
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend(strcat('$DS(\bar{\eta})=$',num2str(b1),'\%'),strcat('$DS(\bar{\eta})=$',num2str(b2),'\%'),'location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'Interpreter','Latex');
   saveas(figure(10), [gpath, 'figNoLiqAdjWelfare.pdf']);
   
   figure(6)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend(strcat('$DS(\bar{\eta})=$',num2str(b1),'\%'),strcat('$DS(\bar{\eta})=$',num2str(b2),'\%'),'location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'Interpreter','Latex');
   saveas(figure(6), [gpath, 'figNoLiqAdjDepo.pdf']);
end

%% now run with the liquidity adjustment
close all
parameters

s.beta_2=1;
s.liqAdj=1;
s.cutoff_eta=.06;
s.mAdj=.25;

b1=.6;
s.beta_1=b1/100/s.r*(1-.18+1);

s.color=[0 0.4470 0.7410];
geteqm2(s);

b2=.5;
s.beta_1=b2/100/s.r*(1-.18+1);
s.color='k';
geteqm2(s);

b3=.4;
s.beta_1=b3/100/s.r*(1-.18+1);
s.color=[0.8500 0.3250 0.0980];
geteqm2(s);

%%
% Save results!
if save_plots

   if ~isfolder(gpath)
       mkdir(gpath)
   end

   figure(10)
   ylabel('$V(\eta)-V(\bar{\eta})$','interpreter','latex')
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend(strcat('$DS(\bar{\eta})=$',num2str(b1),'\%'),strcat('$DS(\bar{\eta})=$',num2str(b2),'\%'),'location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'Interpreter','Latex');
   saveas(figure(10), [gpath, 'figLiqAdjWelfare.pdf']);
   
   figure(6)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend(strcat('$DS(\bar{\eta})=$',num2str(b1),'\%'),strcat('$DS(\bar{\eta})=$',num2str(b2),'\%'),'location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'Interpreter','Latex');
   saveas(figure(6), [gpath, 'figLiqAdjDepo.pdf']);
end
