%first do baseline model
close all
clear

% Change default axes fonts
set(0,'DefaultAxesFontName', 'Times New Roman')
set(0,'DefaultAxesFontSize', 14)

% Change default text fonts
set(0,'DefaultTextFontname', 'Times New Roman')
set(0,'DefaultTextFontSize', 14)

%% Graphics
s.color = 'k';
set(groot, 'DefaultLineLinewidth', 3);
s.gpath = '../figures/';

%%
% Save plots?
save_plots = 1;

close all
% Initialize parameters
parameters;

DS=1.26; %pct spread at etabar

s.beta_1=DS/100/s.r*(1-.16);

gpath = strcat(s.gpath, 'high_phiL/');

% Solve model, with and without fire sales
geteqm2(s);

%%
% Save results!
if save_plots
    if ~isfolder(gpath)
        mkdir(gpath)
    end
   figure(10)
   ylabel('$V(\eta)-V(\bar{\eta})$','interpreter','latex')
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   saveas(figure(10), [gpath, 'welfare_decreasesR1.pdf']);
   
   figure(13)
   xlabel('$\eta$, bank equity wealth share')
   title('') 
   saveas(figure(13), [gpath, 'figPsi0.pdf']);
   
   figure(3)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   saveas(figure(3), [gpath, 'figqR1.pdf']);
   
   
   figure(5)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   saveas(figure(5), [gpath, 'figDepSpreadR1.pdf']);
   
    figure(4)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   saveas(figure(4), [gpath, 'flow_utility_decreasesR1.pdf']);
   
   figure(28)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   saveas(figure(28), [gpath, 'stationary_densityR1.pdf']);
end


%% Now vary gamma

close all

s.issuance=2;
s.color=[0 0.4470 0.7410];
geteqm2(s);



s.issuance=3;
s.color='k';
geteqm2(s);

s.issuance=4;
s.color=[0.8500 0.3250 0.0980];
geteqm2(s);

s.issuance=6;
s.color=[0.9290 0.6940 0.1250];
geteqm2(s);



%%
% Save results!
if save_plots
   figure(9)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend('\gamma=1','\gamma=2 (baseline)','\gamma=3','\gamma=5','location','best');
    set(h,'FontSize',s.fontsize);
   saveas(figure(9), [gpath, 'figVaryGammaWelfare.pdf']);
   
   figure(13)
   xlabel('$\eta$, bank equity wealth share')
   title('') 
   h=legend('\gamma=1','\gamma=2 (baseline)','\gamma=3','\gamma=5','location','best');
    set(h,'FontSize',s.fontsize);
   saveas(figure(13), [gpath, 'figVaryGammaPsi.pdf']);
   
end

%% now with liquidity adjustments

close all
parameters

DS=1.26; %pct spread at etabar

%adjust beta1 because we set beta2=1
s.beta_1=DS/100/s.r*(1-.16+1);

s.beta_2=1;
s.liqAdj=1;
s.cutoff_eta=.06;
s.mAdj=.25;

s.thetastar=1.2;
s.color='r';
geteqm2(s);

s.thetastar=1.1;
s.color='b';
geteqm2(s);

s.thetastar=1.0;
s.color='k';
geteqm2(s);


%%
% Save results!
if save_plots
   figure(9)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend('$\theta(\bar{\eta})=1.2$','$\theta(\bar{\eta})=1.1$','$\theta(\bar{\eta})=1.0$','location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'interpreter','latex');
   saveas(figure(9), [gpath, 'figLiqAdjDivSubWelfare.pdf']);
   
   
end




%% dividend subsidies, log depo utility DS aggressive liqadj
% Save plots?
close all



s.liqAdj=1;
s.cutoff_eta=.1;
s.mAdj=.5;

s.thetastar=1.2;
s.color='r';
geteqm2(s);

s.thetastar=1.1;
s.color='b';
geteqm2(s);

s.thetastar=1.0;
s.color='k';
geteqm2(s);


%%
% Save results!
if save_plots
   figure(9)
   xlabel('$\eta$, bank equity wealth share')
   title('')  
   h=legend('$\theta(\bar{\eta})=1.2$','$\theta(\bar{\eta})=1.1$','$\theta(\bar{\eta})=1.0$','location','best');
    set(h,'FontSize',s.fontsize);
    set(h,'interpreter','latex');
   saveas(figure(9), [gpath, 'figLiqAdjDivSubWelfareAgg.pdf']);
   
   
end


