% Plot the default plots
%
% Written by William Chen, April 2020

% Get out results
theta  = fout(:, 1);
thetap = fout(:, 2);
q      = fout(:, 3);
qp     = fout(:, 4);
psi           = Dyn(:, 1);
sigma_eta_eta = Dyn(:, 2);
sigma_q       = Dyn(:, 3);
mu_eta_eta    = Dyn(:, 4);
mu_q          = Dyn(:, 5);
mu_theta      = Dyn(:, 6);
Sharpe        = Dyn(:, 7);
risk_premium  = Dyn(:, 8);

% Plot!
figure(1)
welfare = q .* (1 + (theta - 1) .* eta);
plot(eta, welfare, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$J(\eta)$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])

figure(2);
flow_utility = q .* (psi - eta) .* s.phiL + s.a * psi + s.a_ * (1 - psi);
plot(eta, flow_utility, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('Flow Utility', 'FontWeight', 'b', 'FontSize', s.fontsize);
legend('Location', 'southeast');

figure(3);
plot(pdf_eta, pdf, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$f(\eta)$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])
legend('Location', 'northwest');

figure(4);
plot(eta, psi, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$\psi$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])
legend('Location', 'southeast');

figure(5);
plot(eta, q, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$q$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])
legend('Location', 'northwest');

figure(6);
plot(eta, sigma_q, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$\sigma_q$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])

figure(7);
plot(eta, sigma_eta_eta, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$\sigma_\eta \cdot \eta$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])

figure(8);
plot(eta, mu_eta_eta, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$\mu_\eta \cdot \eta$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])

figure(9);
normalize_pdf_eta = (pdf_eta - pdf_eta(1)) ./ (pdf_eta(end) - pdf_eta(1)); % map to [0, 1]
plot(normalize_pdf_eta, pdf, 'color', s.color); hold on
xlabel('Level of bank equity normalized to [0, 1]', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$f(\eta)$', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'rotation', 0)
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])
legend('Location', 'northwest');

figure(10);
plot(eta, Sharpe, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('', 'FontWeight', 'b', 'FontSize', s.fontsize);

figure(11);
plot(eta, risk_premium, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('', 'FontWeight', 'b', 'FontSize', s.fontsize);

figure(101)
 welfare=welfare-welfare(end);
plot(eta, welfare, 'color', s.color); hold on
xlabel('$\eta$, bank equity wealth share', 'FontWeight', 'b', 'FontSize', s.fontsize);
ylabel('$J(\eta)$ Normalized', 'FontWeight', 'b', 'FontSize', s.fontsize);
set(get(gca, 'ylabel'), 'Units', 'Normalized', 'Position', [-0.1, 0.5, 0])
