% This function solves for equilibrium, potentially with leverage
% constraints.  Takes 3 inputs: 'color' (e.g. 'k') is plot color; s is the
% structure of parameters; K is the max leverage: when numeric this is max
% leverage; K='e' corresponds to VaR constraint; K=0 corresponds to
% unconstrained.
%
% written by Greg Phelan
function [fout, etaout, Dyn, s]=GetEqm(color,s,K)
tic
s.K=K; %Leverage constraint.  K=0 corresponds to no constraint (unconstrained)
s.color=color; %add to structure to pass to other functions

OP=optimset('Display','off');
y1max=1;%s.alpha^s.alpha*(1-s.alpha)^(1-s.alpha); %optimal static land allocation

%get initial conditions for eta=0
x=fsolve(@init_cond,[y1max/(s.r-s.g) s.alpha],OP,s);
s.q_ = x(1); s.l0=x(2);

if s.phiL==s.phiI
    s.qmax=y1max/(s.r-s.g);
    s.lmax=s.alpha;
else
x2=fsolve(@max_cond,[y1max/(s.r-s.g) s.alpha],OP,s);
s.qmax=x2(1);
s.lmax=x2(2); %s.qmax = (s.alpha^s.alpha*(1-s.alpha^(1-s.alpha)))/(s.r - s.g);
end
q_=s.q_; qmax=s.qmax; lambda_=s.l0; lmax=s.lmax;
dataset(q_,qmax,lambda_,lmax)

s.end=s.lmax;
etaspan = [s.start s.end];
F0 = [1 -1e6 s.q_ 0]';  % the last coordinate is the derivative q'(0)
                        % found in the following loop

odeevnt =@(eta,f) evntfcn(eta,f,s);                        
options = odeset('events',odeevnt,'AbsTol',1e-8);  
% this function terminates integration of the ode when q exceeds qmax, 
% or f'(eta) or q'(eta) reaches 0 
                                    
odefun = @(eta,f) fnct(eta, f, s);

%the true ODE is a boundary-value problem, which is much easier to solve as
%an initial-value problem (IVP).  To do this, we guess initial values for
%theta'(0) and q'(0) and search so that boundary conditions match at \eta*.
%Because theta'(0)=infty, we approximate above; we search over q'(0) using
%bisection method.

QL = 0; QR = 1e7;
for iter = 1:30
    F0(4) = (QL + QR)/2;  % this is q'(0)
    F0(3) = F0(4)*s.start+s.q_; %to correct for the fact that we're starting 
                          % away from zero and the derivative is very large
    
    [etaout,fout,~,~,IE] = ode45(odefun,etaspan,F0,options);
    
    if IE == 3, % if q'(eta) has reached zero, we 
        QL = F0(4);  % increase q'(0)
    else
        QR = F0(4);  % else we reduce q'(0)
    end
end
s.QL=QL;
s.QR=QR;
% normalize theta so that theta(eta*) = 1
N = length(etaout);
normalization = fout(N,1);
fout(:,1:2) = fout(:,1:2)/normalization;

mup=max(fout(:,2));
qp=min(fout(:,4));
dataset(IE)
dataset(QL,QR,mup,qp)
%set eta* derivs
 fout(end,2)=0; fout(end,4)=0;
[Dyn, expert_premium,Sharpe]=display_results(etaout,fout,s);
s.N=length(Dyn);

s.expert_premium=expert_premium;

ergocalc(etaout(1:s.N),fout(1:s.N,:),Dyn,Sharpe,color,s);
timetoreach(etaout(1:s.N),fout(1:s.N,:),Dyn,color,s);
if s.quick==0;
s=welfarecalc(etaout(1:s.N),fout(1:s.N,:),Dyn,s,color);
end

if s.simulation==1
simulation(etaout(1:s.N),fout(1:s.N,:),Dyn,s)
end

s.fout0=fout;
s.etaout0=etaout;

toc