% 
%
% written by Greg Phelan
function [fout etaout s]=GetEqmIssuance(color,s,K)
% if s.display_time
    tic
% end
% Grab settings
s.color = color;
OP      = optimset('Display', 'off');

% Set leverage
s.K = K;

% Compute max and min asset price
y1max  = s.a;
s.q_   = y1max / (s.r - s.g_);
s.qmax = y1max/ (s.r - s.phiL - s.g);
q_ = s.q_; qmax = s.qmax;
dataset(q_, qmax);

% Set lower boundary on eta
s.mult = 1 / s.issuance;

% Set up ODE
odeevnt = @(eta, f) evntfcn2(eta, f, s); % terminal conditions
options = odeset('events',odeevnt,'AbsTol',1e-3);  
% this function terminates integration of the ode when q exceeds qmax, 
% or f'(eta) or q'(eta) reaches 0 
                                    
odefun = @(eta,f) fnct(eta, f, s);

% Set up initial conditions
F0 = [5 -1e-5 s.q_ 1e-5]';       % for eqm differential equations
ininit=[.2*s.q_+.8*s.qmax; .02]; % guess for q(eta_) and eta_

in0 = fminsearch(@(in) getendpoints(in,s,odefun,options),ininit);
    F0(1)=s.issuance;
    F0(4)=1e-5;
    F0(3) = in0(1);  % this is q(eta0)
    F0(2)=-(s.issuance-1)/in0(2); 
    etaspan = [in0(2) s.end];
    

    
    [etaout,fout] = ode45(odefun,etaspan,F0,options);
    dataset(in0)
    fout(end-1:end,:)
%     if IE == 3, % if theta has reached 1, we 
%         QL = F0(4);  % increase q'(0)
%     else
%         QR = F0(4);  % else we reduce q'(0)
%     end
%     
% 
% % normalize theta so that theta(eta*) = 1
% N = length(etaout);
% normalization = fout(N,1);
% fout(:,1:2) = fout(:,1:2)/normalization;
% 
% mup=max(fout(:,2));
% qp=min(fout(:,4));
% dataset(IE)
% dataset(QL,QR,mup,qp)
%set eta* derivs
%  fout(end,2)=0; fout(end,4)=0;
[Dyn, Sharpe] = display_results(etaout,fout,s);
s.N=length(Dyn);

% if s.simulation==1
% simulation(etaout(1:s.N),fout(1:s.N,:),Dyn,s)
% end


ergocalc(etaout(1:s.N),fout(1:s.N,:),Dyn,Sharpe,color,s);
% timetoreach(etaout(1:s.N),fout(1:s.N,:),Dyn,color,s);

% if s.quick==0;
% welfarecalc(etaout(1:s.N),fout(1:s.N,:),Dyn,s,color);
% end

s.fout0=fout;
s.etaout0=etaout;

% if s.display_time
    toc
% end
end