function [fout, etaout, Dyn, pdf, pdf_eta, cdf, s]=GetEqmIssuanceNoPlots(s, K)
% written by Greg Phelan and William Chen, April 2020

    if s.display_time
        tic;
    end

    % Set leverage
    s.K = K;

    % Compute max and min asset price
    y1max  = s.a;
    s.q_   = y1max / (s.r - s.g_);
    s.qmax = y1max/ (s.r - s.phiL - s.g);

    % Set up ODE
    odeevnt = @(eta, f) evntfcn2(eta, f, s); % terminal conditions
    options = odeset('events', odeevnt, 'AbsTol' ,1e-3);  
    % this function terminates integration of the ode when q exceeds qmax, 
    % or f'(eta) or q'(eta) reaches 0 

    odefun = @(eta,f) fnct(eta, f, s);

    % Set up initial conditions
    F0 = [5 -1e-5 s.q_ 1e-5]';       % for eqm differential equations
    ininit=[.2*s.q_+.8*s.qmax; .02]; % guess for q(eta_) and eta_
    if isfield(s, 'tailrisk')
        if ~isfield(s, 'eta_TR')
            error('To implement tail risk insurance, user must specify the lower barrier in the parameters struct with field eta_TR.');
        end
        if s.tailrisk
            ininit(2) = 1e2 * s.eta_TR; % ininit(2) is now theta(eta_), not eta_
        end
    end

    % Find solution which minimizes L2 norm of boundary conditions
    [in0, s.out_min, s.exitflag] = fminsearch(@(in) getendpoints(in,s,odefun,options),ininit);
    F0(1) = s.issuance;
    F0(4) = s.qp_;
    F0(3) = in0(1);  % this is q(eta_)
    F0(2) = -(s.issuance-1) / in0(2);  % theta'(eta_)
    etaspan = [in0(2) s.end];
    
    if isfield(s, 'tailrisk')
        if s.tailrisk
            etaspan = [s.eta_TR, s.end];
            F0(1) = in0(2);
            F0(2) = -in0(2) / s.eta_TR;
        end
    end
    
    % Produce results with new boundary conditions
    [etaout, fout] = ode45(odefun, etaspan, F0, options);

    if sum(fout(:,4)<0)>0
        N = find(fout(:,4)<0,1);%length(etaout);
    else
        N=length(etaout);
    end
    s.N = N;
    Dyn = zeros(N, 8);
    fp  = zeros(N,4);

    % calculate the psi, as well as drifts and volatilities 
    for n = 1:N
        [fp(n,:), Dyn(n,:), ~, ~] = fnct(etaout(n), fout(n,:), s);
    end

    [pdf, pdf_eta, cdf] = ergocalc_no_plots(etaout(1:s.N), Dyn, s);

    if s.display_time
        toc;
    end
end