function [Dyn, expert_premium, Sharpe]=display_results(etaout,fout,s)

start=s.gstart;
color=strcat(s.line,s.color);

if sum(fout(:,4)<0)>0
N = find(fout(:,4)<0,1);
else
    N=length(etaout);
end
s.N=N;
Dyn = zeros(N, 8);
fp=zeros(N,4);
Sharpe=zeros(N,1);
expert_premium=zeros(N,1);

% calculate the psi, as well as drifts and volatilities
for n = 1:N,
    [fp(n,:), Dyn(n,:),expert_premium(n,:),Sharpe(n,:)] = fnct(etaout(n), fout(n,:), s);
end


etastar=max(etaout);

Leverage=Dyn(1:N-1,1)./etaout(1:N-1)-1;



%plot leverage
figure(1); hold on
    plot(etaout(1:N-1),Leverage,color,'linewidth',s.width);
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Leverage','FontSize',s.fontsize,'FontWeight','b')
    title('Aggregate Bank Leverage','FontSize',s.fontsize)
    xlim([s.start 1.05*etastar])


%plot drifts, vols
figure(2);
    subplot(2,2,1); hold on
    plot(etaout(1:N-1), Dyn(1:N-1, 4)./etaout(1:N-1), color,'linewidth',s.width);
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\mu_\eta$  ','fontsize',14,'Rotation',0,'FontWeight','b');
    xlim([start 1.05*etastar])
    ylim([0 1.05*max(Dyn(1:N-1, 4)./etaout(1:N-1))]);
    title('Drift of bank equity','FontSize',s.fontsize)

    subplot(2,2,2); hold on
    plot(etaout(1:N-1), Dyn(1:N-1, 2)./etaout(1:N-1), color,'linewidth',s.width);
    ylabel('\sigma_\eta ','fontsize',14,'Rotation',0,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])
    ylim([0 1.05*max(Dyn(1:N-1, 2)./etaout(1:N-1))]);
    title('Volatility of bank equity','FontSize',s.fontsize)

    subplot(2,2,3); hold on
    plot(etaout(1:N-1), Dyn(1:N-1,5), color,'linewidth',s.width);
    ylabel('\mu_q ','fontsize',14,'Rotation',0,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])
    title('Drift of land price','FontSize',s.fontsize)

    subplot(2,2,4); hold on
    plot(etaout(1:N-1), Dyn(1:N-1,3), color,'linewidth',s.width);
    ylabel('\sigma_q ','fontsize',14,'Rotation',0,'FontWeight','b');
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    xlim([s.start 1.05*etastar])
    title('Volatility of land price','FontSize',s.fontsize)

max_leverage=max(Leverage); lambdastar=Dyn(N-1,8); Levstar=Leverage(end);
dataset(max_leverage,etastar,lambdastar,Levstar)

figure(3); hold on
    plot(etaout(1:N-1), fout(1:N-1,3), color,'linewidth',s.width);
    title('Price of Land, q(\eta)','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$q$','FontSize',s.fontsize,'Rotation',0,'FontWeight','b')


%plot productivity
productivity=1;
liq=((Dyn(1:N-1,1)-etaout(1:N-1))).*fout(1:N-1,3).*depo_spread(Dyn(1:N-1,1),etaout(1:N-1),fout(1:N-1,1),s);
pmax=1.01*(max(productivity)+max(liq)); pmin=.98*min(productivity);

figure(4); hold on
    plot(etaout(1:N-1), productivity+liq, color,'linewidth',s.width);
    xlabel('$\eta$','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Flow Utility','FontSize',s.fontsize,'FontWeight','b')
    title('Output and Liquidity','FontSize',s.fontsize)
    xlim([start 1.05*etastar])


%plot flow utility
figure(5); hold on
    plot(etaout(1:N-1), productivity+liq, color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Flow Utility','FontSize',s.fontsize,'FontWeight','b')
    title('Output and Liquidity','FontSize',s.fontsize,'FontWeight','b')
    xlim([start 1.05*etastar])

figure(13); hold on
    plot(etaout(1:N-1), Dyn(1:N-1,1), color,'linewidth',s.width);
    title('Bank Holdings','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\psi$','FontSize',s.fontsize,'FontWeight','b')

welfare=(1+(fout(1:N-1,1)-1).*etaout(1:N-1)).*fout(1:N-1,3);
%Household Welfare
figure(9); hold on
    plot(etaout(1:N-1), welfare, color,'linewidth',s.width);
    title('Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$J(\eta)$','FontSize',s.fontsize,'FontWeight','b')

%plot intermediary welfare
figure(12); hold on
    plot(etaout(1:N-1), fout(1:N-1,1).*etaout(1:N-1).*fout(1:N-1,3), color,'linewidth',s.width);
    title('Expected Value of Bank Dividends','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$q\theta\eta$','FontSize',s.fontsize,'FontWeight','b')

figure(32); hold on
    plot(etaout(1:N-1), ones(size(etaout(1:N-1))), '--k');
    plot(etaout(1:N-1), welfare./(welfare(end)), color,'linewidth',s.width);
    title('Normalized Welfare','FontSize',s.fontsize)
    xlim([start 1.05*etastar])
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$J/J(\bar{\eta})$','FontSize',s.fontsize,'FontWeight','b')

figure(15)
    plot(etaout(1:N),fout(1:N,1),color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('$\theta$','FontSize',s.fontsize,'FontWeight','b','Rotation',0)
    title('$\theta(\eta)$')
    xlim([start 1.05*etastar])
    ylim([.9 5])

figure(25)
    plot(etaout(1:N),Sharpe(1:N,1),color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Sharpe','FontSize',s.fontsize,'FontWeight','b','Rotation',0)
    title('Sharpe Ratio')
    xlim([start 1.05*etastar])

figure(33)
    plot(etaout(1:N),expert_premium(1:N,1),color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Premium','FontSize',s.fontsize,'FontWeight','b')
    title('Expert Premium')
    xlim([start 1.05*etastar])

    psi=Dyn(1:N-1,1);
    theta=fout(1:N-1,1);
    deposit_spread=depo_spread(psi,etaout(1:N-1),theta,s);
figure(34)
    plot(etaout(1:N-1),deposit_spread,color,'linewidth',s.width); hold on
    xlabel('$\eta$, level of bank equity','FontSize',s.fontsize,'FontWeight','b')
    ylabel('Deposit Spread','FontSize',s.fontsize,'FontWeight','b')
    title('Deposit Spread')
    xlim([start 1.05*etastar])
