function [value, isterminal, direction] = evntfcn2(eta, F,s) 
% [value,isterminal,direction] = evntfcn(eta, F) returns three
% variables used by ode45 to determine when to terminate integration
%

% Default boundary conditions.
% (1) q'(etabar) = 0
% (2) theta'(etabar) * etabar + theta(etabar) - 1
% (3) theta(etabar) = s.thetastar
value = [F(4), F(2) * eta + s.thetastar - 1, (F(1) - s.thetastar)];
isterminal = [1 1 1];
direction = [0 0 0]; % event occurs whether we get there from above or below 

% Check if dividends are restricted
if isfield(s, 'restrict_dividends')
    if ~isfield(s, 'eta_DR')
        error('To restrict dividends, user must add a field to parameters struct called eta_DR');
    end
    if s.restrict_dividends
        % theta(etabar) no longer has to be 1
        value(3) = eta - s.eta_DR;
    end
end

