function out=getendpoints(in,s,odefun,options)
% This function returns the L2 norm of boundary conditions
%
% Written by Greg Phelan and William Chen
    
% Set initial conditions
F0(1) = s.issuance;                            % theta(eta_)
F0(4) = s.qp_;                                 % q'(eta_)
F0(3) = in(1);                                 % q(eta_)
F0(2) = -( s.issuance-1) / in(2); % theta'(eta_)

etaspan = [in(2) s.end];

if isfield(s, 'tailrisk')
    if ~isfield(s, 'eta_TR')
        error('To implement tail risk insurance, user must specify the lower barrier in the parameters struct with field eta_TR.');
    end
    if s.tailrisk
        % Boundary condition at eta_ is
        % theta'(eta_) = -theta(eta_) / eta_.
        % in(2) also changes to be theta(eta_).
        F0(1) = in(2);
        F0(2) = -in(2) / s.eta_TR;
        etaspan = [s.eta_TR, s.end];
    end
end

[etaout, fout] = ode45(odefun, etaspan, F0, options);

ThetaSP = 10 * (fout(end, 2) * etaout(end) + fout(end, 1) -1);
% ThetaSP=10*(fout(end,2)-0);
% we write it this way to accommodate when thetabar \neq 1 b/c policy

out=[100 * (fout(end, 1) - s.thetastar); %theta(etabar) is correct
    ThetaSP; %theta(etabar) smooth pasting
    fout(end, 4)]; %q(etabar) smooth pasting

% If restricting dividends, change out(1)
if isfield(s, 'restrict_dividends')
    if s.restrict_dividends
        % theta(etabar) no longer has to be 1
        out(1) = 10 * (etaout(end) - s.eta_DR);
    end
end

out = out' * out; % L2 norm
end