% This script assesses welfare results of tail risk insurance.
%
% Written by William Chen, April 2020

clear; clc; close all;
addpath parameter_specs
addpath eqm_functions

% What to run?
solve_eqm  = 1;         % Solve for equilibrium?
do_plots   = 1;         % are we making plots?
save_plots = 1;         % are we saving plots?
color_vec  = {[1, 0.5, 0], 'red', [.5, 0, .7], 'blue'};

% Initialize parameters
spec1;
s.tailrisk = 1;
tailrisk_eta = [.04, .043, .046, 0];
s.display_time = 0;
gpath = strcat(s.gpath, 'tailrisk/');

% Pre allocate storage
fout_TR    = cell(length(tailrisk_eta), 1); eta_TR = cell(length(tailrisk_eta), 1);
Dyn_TR     = cell(length(tailrisk_eta), 1); pdf_TR = cell(length(tailrisk_eta), 1);
pdf_eta_TR = cell(length(tailrisk_eta), 1); cdf_TR = cell(length(tailrisk_eta), 1);
s_TR       = cell(length(tailrisk_eta), 1);

% Solve model for multiple tail risk insurance boundaries
if solve_eqm
    disp('Solving the model varying lvgcons');
    tic;
    for i = 1:length(tailrisk_eta)
        s.eta_TR = tailrisk_eta(i);
        if tailrisk_eta(i) == 0
            s.tailrisk = 0;
        end
        [fout_TR{i}, eta_TR{i}, Dyn_TR{i}, pdf_TR{i}, pdf_eta_TR{i}, cdf_TR{i}, s_TR{i}] = ...
            GetEqmIssuanceNoPlots(s, 0);
    end
    toc;
end

% Plot results!
if do_plots
    disp('Plotting results for varying lvgcons . . .');

    legend_labels = cell(length(tailrisk_eta), 1);
    for i = 1:length(tailrisk_eta)
        fout    = fout_TR{i};    eta = eta_TR{i};
        Dyn     = Dyn_TR{i};     pdf = pdf_TR{i};
        pdf_eta = pdf_eta_TR{i}; cdf = cdf_TR{i};
        s       = s_TR{i};
        s.color = color_vec{i};
        default_plots;
        legend_labels{i} = ['$\eta_{TR} = $', num2str(round(tailrisk_eta(i), 2)), '\%'];
    end
    legend_labels{end} = 'CE';
    for i = 1:11
        figure(i);
        legend(legend_labels, 'Interpreter', 'latex', 'FontSize', s.fontsize); hold off
        if i == 2
            legend('Location', 'northeast');
        end            
    end
    if save_plots
        if ~isfolder(gpath)
            mkdir(gpath)
        end
        
        disp('Saving results for varying leverage constraints . . .');
        saveas(figure(1), [gpath 'welfare.pdf']);
        saveas(figure(2), [gpath 'flow_utility.pdf']);
        saveas(figure(3), [gpath, 'stationary_density.pdf']);
        saveas(figure(5), [gpath, 'q.pdf']);
    end
end
