% This script generates results of robustness when
% varying the cost of equity issuance.
%
% Written by William Chen, April 2020

clear; clc; close all;
addpath parameter_specs
addpath eqm_functions

% What to run?
solve_eqm  = 1;         % Solve for equilibrium?
do_plots   = 1;         % are we making plots?
save_plots = 1;         % are we saving plots?
color_vec  = {[1, 0.5, 0], 'red', [.5, 0, .7], 'blue'};

% Initialize parameters
spec5;
s.display_time = 0;
gpath = strcat(s.gpath, 'vary_equity_issuance_cost/');

% Pre allocate storage
fout_issuance    = cell(length(vec_issuance), 1); eta_issuance = cell(length(vec_issuance), 1);
Dyn_issuance     = cell(length(vec_issuance), 1); pdf_issuance = cell(length(vec_issuance), 1);
pdf_eta_issuance = cell(length(vec_issuance), 1); cdf_issuance = cell(length(vec_issuance), 1);
s_issuance       = cell(length(vec_issuance), 1); 

% Solve model for multiple levels of equity issuance costs
if solve_eqm
    disp('Solving the model varying gamma');
    tic;
    for i = 1:length(vec_issuance)
        s.issuance = vec_issuance(i);
        [fout_issuance{i}, eta_issuance{i}, Dyn_issuance{i}, pdf_issuance{i}, pdf_eta_issuance{i}, cdf_issuance{i}, s_issuance{i}] = ...
            GetEqmIssuanceNoPlots(s, 0);
    end
    toc;
end

% Plot results!
if do_plots
    disp('Plotting results for varying gamma . . .');

    legend_labels = cell(length(vec_issuance), 1);
    for i = 1:length(vec_issuance)
        fout    = fout_issuance{i};    eta = eta_issuance{i};
        Dyn     = Dyn_issuance{i};     pdf = pdf_issuance{i};
        pdf_eta = pdf_eta_issuance{i}; cdf = cdf_issuance{i};
        s       = s_issuance{i};
        s.color = color_vec{i};
        default_plots;
        legend_labels{i} = strcat('$\gamma = $', num2str(vec_issuance(i) - 1));            
    end
    for i = 1:11
        figure(i);
        legend(legend_labels, 'Interpreter', 'latex', 'FontSize', s.fontsize); hold off
    end
    if save_plots
       if ~isfolder(gpath)
           mkdir(gpath)
       end
       disp('Saving results for varying gamma . . .');
       saveas(figure(1), [gpath 'welfare.pdf']);
       saveas(figure(2), [gpath 'flow_utility.pdf']);
       saveas(figure(3), [gpath, 'stationary_density.pdf']);
       saveas(figure(4), [gpath, 'psi.pdf']);
       saveas(figure(7), [gpath, 'sigma_eta_eta.pdf']);
       saveas(figure(8), [gpath, 'mu_eta_eta.pdf']);
       saveas(figure(9), [gpath, 'stationary_density_normalize.pdf']);
    end        
end

