% This script generates results of robustness when
% varying phiL
%
% Written by William Chen, April 2020

clear; clc; close all;
addpath parameter_specs
addpath eqm_functions

% What to run?
solve_eqm  = 1;         % Solve for equilibrium?
do_plots   = 1;         % are we making plots?
save_plots = 1;         % are we saving plots?
color_vec  = {[1, 0.5, 0], 'red', [.5, 0, .7]};

% Initialize parameters
spec7;
s.display_time = 0;
gpath = strcat(s.gpath, 'vary_phiL/');

% Pre allocate storage
fout_phiL    = cell(length(vec_phiL), 1); eta_phiL = cell(length(vec_phiL), 1);
Dyn_phiL     = cell(length(vec_phiL), 1); pdf_phiL = cell(length(vec_phiL), 1);
pdf_eta_phiL = cell(length(vec_phiL), 1); cdf_phiL = cell(length(vec_phiL), 1);
s_phiL       = cell(length(vec_phiL), 1);

% Solve model for multiple levels of phiL
if solve_eqm
    disp('Solving the model varying phiL');
    tic;
    for i = 1:length(vec_phiL)
        s.phiL = vec_phiL(i);
        [fout_phiL{i}, eta_phiL{i}, Dyn_phiL{i}, pdf_phiL{i}, pdf_eta_phiL{i}, cdf_phiL{i}, s_phiL{i}] = ...
            GetEqmIssuanceNoPlots(s, 0);
    end
    toc;
end

% Plot results!
if do_plots
    disp('Plotting results for varying phiL . . .');

    legend_labels = cell(length(vec_phiL), 1);
    for i = 1:length(vec_phiL)
        fout    = fout_phiL{i};    eta = eta_phiL{i};
        Dyn     = Dyn_phiL{i};     pdf = pdf_phiL{i};
        pdf_eta = pdf_eta_phiL{i}; cdf = cdf_phiL{i};
        s       = s_phiL{i};
        s.color = color_vec{i};
        default_plots;
        legend_labels{i} = ['$\phi_L = $', num2str(round(vec_phiL(i), 3) * 100), '\%'];
    end
    for i = 1:11
        figure(i);
        legend(legend_labels, 'Interpreter', 'latex', 'FontSize', s.fontsize); hold off
    end
    
    figure(101);
    legend(legend_labels, 'Interpreter', 'latex', 'FontSize', s.fontsize); hold off
    
    if save_plots
       if ~isfolder(gpath)
           mkdir(gpath)
       end
       disp('Saving results for varying phiL . . .');
       saveas(figure(101), [gpath 'welfare.pdf']);
       saveas(figure(2), [gpath 'flow_utility.pdf']);
       saveas(figure(3), [gpath, 'stationary_density.pdf']);
       saveas(figure(4), [gpath, 'psi.pdf']);
       saveas(figure(7), [gpath, 'sigma_eta_eta.pdf']);
       saveas(figure(8), [gpath, 'mu_eta_eta.pdf']);
       saveas(figure(9), [gpath, 'stationary_density_normalize.pdf']);
    end
end
